# Aviso

Aviso is a software developed by ECMWF that allows the notification of  **time-critical events** across HPC and Cloud systems in 
order to enable workflows among multiple domains.

It allows users to:

* Define events that require notification
* Define triggers to be executed once a notification is received
* Send and receive notifications

This enables the creation of automatic workflows, timely triggered as events are notified.
 

The documentation can be found at https://pyaviso.readthedocs.io/ \
Examples demonstrating the usage of aviso for ECMWF notifications can be found at https://github.com/ecmwf/aviso-examples